# Copyright 2016 Internap.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import mock

import oslo_messaging

from almanach.collector import service

from almanach.tests.unit import base


class TestService(base.BaseTestCase):

    def setUp(self):
        super(TestService, self).setUp()
        self.listener = mock.Mock()
        self.listeners = [self.listener]
        self.service = service.CollectorService(self.listeners, self.config.collector.thread_pool_size)

    def test_start_when_listener_started_successfully(self):
        self.service.start()
        self.listeners[0].start.assert_called_once_with(override_pool_size=self.config.collector.thread_pool_size)
        self.assertTrue(self.service.started)

    def test_start_when_listener_failed_to_start(self):
        self.listener.start.side_effect = oslo_messaging.exceptions.MessagingException('Some Error')
        self.assertRaises(oslo_messaging.exceptions.MessagingException, self.service.start)
        self.assertFalse(self.service.started)

    def test_stop_when_service_started_successfully(self):
        self.service.started = True
        self.service.stop()
        self.listener.stop.assert_called_once()

    def test_stop_when_service_failed_to_start(self):
        self.service.stop()
        self.listener.stop.assert_not_called()



# Copyright 2016 Internap.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from almanach.tests.tempest.tests.scenario import base


class TestVolumeCreationScenario(base.BaseAlmanachScenarioTest):
    def test_create_volume(self):
        volume = self.create_volume()

        self.wait_for_notification(self._check_that_a_new_entity_is_created,
                                   volume)

        entities = self.get_tenant_entities(volume['os-vol-tenant-attr:tenant_id'])
        self.assertEqual(1, len(entities))
        self.assertEqual(volume['id'], entities[0]['entity_id'])
        self.assertEqual(volume['volume_type'], entities[0]['volume_type'])
        self.assertIsNotNone(entities[0]['start'])
        self.assertIsNone(entities[0]['end'])

    def _check_that_a_new_entity_is_created(self, volume):
        entities = self.get_tenant_entities(volume['os-vol-tenant-attr:tenant_id'])
        return len(entities) == 1



# Copyright 2016 Internap.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from almanach.tests.tempest.tests.scenario import base


class TestVolumeSuppressionScenario(base.BaseAlmanachScenarioTest):

    def test_delete_volume(self):
        volume = self._delete_volume()
        entities = self.get_tenant_entities(volume['os-vol-tenant-attr:tenant_id'])

        self.assertEqual(1, len(entities))
        self.assertEqual(volume['id'], entities[0]['entity_id'])
        self.assertEqual(volume['volume_type'], entities[0]['volume_type'])
        self.assertIsNotNone(entities[0]['start'])
        self.assertIsNotNone(entities[0]['end'])

    def _delete_volume(self):
        volume = self.create_test_volume()
        self.volumes_client.delete_volume(volume['id'])
        self.volumes_client.wait_for_resource_deletion(volume['id'])
        return volume
